=====================
 Glance Contributors
=====================

Summary
-------

The OpenStack community is seeking contributors and maintainers for
:doc:`Glance <../../projects/glance>`, the disk image management service for
OpenStack clouds.

Business Case
-------------

Glance is a critical service in OpenStack: it is a hard requirement for Nova,
and as such is used in practically every OpenStack cloud. Due to the small size
of the current Glance team, any investment in upstream Glance maintenance would
result in a meaningful reduction in business risk for any organisation that
relies on OpenStack clouds.

As a relatively small component that is nevertheless fundamental to OpenStack
clouds, Glance also presents a good opportunity for an organisation to build
expertise in OpenStack development processes that it can later apply to
furthering its other interests in OpenStack.

Technical Details
-----------------

Glance is looking for new contributors who would be willing to provide reviews,
to work on bugs, or to work on new features. Glance has welcomed interns,
junior developers, and more senior developers. In every case, it is a great way
to grow and contribute to OpenStack.

Part of the work of a maintainer is in simply responding to changes (in
dependent libraries, or other OpenStack components), and in investigating and
fixing bugs as they are discovered.

However, Glance is not feature-complete - there remain opportunities to take
meaningful ownership of parts of the project by reducing technical debt or
`implementing features`_.

Finally, maintainers can help ensure that the :doc:`../../../goals/index` for
each cycle are implemented. This is essential for allowing the OpenStack
project as a whole to move forward in cases where changes must be co-ordinated
across every project.

Contact
-------

You are welcome to contact the :doc:`Glance PTL <../../projects/glance>` (Erno
Kuvaja) or any member of the `core review team`_ directly for advice on how to
get involved.

To get started, join the Glance IRC channel (``#openstack-glance`` on `OFTC
<https://www.oftc.net/>`_) or reach out to the OpenStack-discuss `mailing list`_
using the ``[glance]`` tag in the subject line.

.. _`implementing features`: https://specs.openstack.org/glance-specs/specs/untargeted/index.html
.. _`core review team`: https://review.opendev.org/#/admin/groups/13,members
.. _`mailing list`: http://lists.openstack.org/cgi-bin/mailman/listinfo/openstack-discuss
